@@ -77,7 +77,7 @@ def monitored_channel(channel, monitored_channels):
 
     
 def play_sound(args):
-    print ("hello")
+    a = 1
     #filename = u"~/bin/sounds/" + args[u'sound_file'] + u".ogg"    
     #call([u"play", u"-q", filename])    
 
